@@ -145,8 +145,11 @@ class SmartProxyView(View):
 
         # Apply request decorators, if provided
         for decorator in self.request_decorators:
-            current_request = decorator(current_request,
-                                        session=request.session)
+            try:
+                current_request = decorator(current_request,
+                                            session=request.session)
+            except Exception as e:
+                logger.exception(e)
 
         # Return the SmartProxyRequest object
         return current_request
